@@ -35,8 +35,23 @@ class MinosSetup(Generic[T]):
     _config: MinosConfig = Provide["config"]
 
     def __init__(self, *args, already_setup: bool = False, **kwargs):
-        self.already_setup = already_setup
-        self.already_destroyed = False
+        self._already_setup = already_setup
+
+    @property
+    def already_setup(self) -> bool:
+        """Already Setup getter.
+
+        :return: A boolean value.
+        """
+        return self._already_setup
+
+    @property
+    def already_destroyed(self) -> bool:
+        """Already Destroy getter.
+
+        :return: A boolean value.
+        """
+        return not self._already_setup
 
     @classmethod
     def from_config(cls, *args, config: MinosConfig = None, **kwargs) -> T:
@@ -66,10 +81,9 @@ class MinosSetup(Generic[T]):
 
         :return: This method does not return anything.
         """
-        if not self.already_setup:
+        if not self._already_setup:
             await self._setup()
-            self.already_setup = True
-        self.already_destroyed = False
+            self._already_setup = True
 
     async def _setup(self) -> NoReturn:
         return
@@ -82,10 +96,9 @@ class MinosSetup(Generic[T]):
 
         :return: This method does not return anything.
         """
-        if not self.already_destroyed:
+        if self._already_setup:
             await self._destroy()
-            self.already_destroyed = True
-        self.already_setup = False
+            self._already_setup = False
 
     async def _destroy(self) -> NoReturn:
         """Destroy miscellaneous repository things."""
